@@ -16,6 +16,7 @@ if ty.TYPE_CHECKING:
 
 @dtcs.dataclass
 class CommandCtx(aur.util.AutoRepr):
+   flux: FluxClient
    msg_ctx: MessageCtx
    author_ctx: AuthorAwareCtx
    auth_ctxs: ty.List[AuthAwareCtx]
@@ -68,10 +69,7 @@ class GuildAwareCtx(ConfigCtx):
 #       return self.guild_
 
 
-class AuthorAwareCtx(ConfigCtx):
-   def __init__(self, flux: FluxClient, **kwargs):
-      super().__init__(flux=flux, **kwargs)
-
+class AuthorAwareCtx:
    @property
    @abc.abstractmethod
    def author(self) -> ty.Union[discord.User, discord.Member]: ...
@@ -112,8 +110,8 @@ class ManualAuthCtx(AuthAwareCtx):
 
 
 class ManualAuthorCtx(AuthorAwareCtx):
-   def __init__(self, flux: FluxClient, author: ty.Union[discord.User, discord.Member], **kwargs):
-      super().__init__(flux=flux, **kwargs)
+   def __init__(self, author: ty.Union[discord.User, discord.Member]):
+      super().__init__()
       self.author_ = author
 
    @property
@@ -150,7 +148,7 @@ class GuildMemberCtx(AuthAwareCtx, GuildAwareCtx):
 
 
 class MessageCtx(AuthAwareCtx, AuthorAwareCtx, metaclass=ABCMeta):
-   def __init__(self, flux: FluxClient, message: discord.Message, **kwargs):
+   def __init__(self, flux: FluxClient, message: discord.Message, **kwargs: ty.Any):
       super().__init__(flux=flux, **kwargs)
       self.message = message
 
@@ -165,7 +163,7 @@ class MessageCtx(AuthAwareCtx, AuthorAwareCtx, metaclass=ABCMeta):
 
 class GuildTextChannelCtx(GuildAwareCtx, _MessageableCtx):
 
-   def __init__(self, flux: FluxClient, channel: ty.Union[discord.TextChannel, discord.DMChannel, discord.GroupChannel], **kwargs):
+   def __init__(self, flux: FluxClient, channel: discord.TextChannel, **kwargs):
       super().__init__(flux=flux, **kwargs)
       self.channel = channel
 
