@@ -1,22 +1,17 @@
 from __future__ import annotations
-import os
 
 import asyncio as aio
-import logging as __logging
-
 import typing as ty
 
 import aiohttp
 import aurcore as aur
-
 import discord.errors
 import discord.ext
-
 from aurcore import EventRouter
+from loguru import logger
 
 from .config import Config
-from .context import GuildMessageCtx, AuthAwareCtx, CommandCtx, MessageCtx
-from loguru import logger
+from .context import CommandCtx, GuildMessageCtx, MessageCtx
 
 if ty.TYPE_CHECKING:
    import discord
@@ -27,7 +22,7 @@ aur.log.setup()
 
 
 class FluxEvent(aur.Event):
-   def __init__(self, flux, __event_name, *args, **kwargs):
+   def __init__(self, flux: FluxClient, __event_name: str, *args, **kwargs):
       super().__init__(__event_name, *args, **kwargs)
       self.flux: FluxClient = flux
 
@@ -46,9 +41,9 @@ class FluxClient(discord.Client):
          self,
          name: str,
          admin_id: int,
-         parent_router: EventRouterHost = None,
-         builtins=True,
-         status: str = None,
+         parent_router: EventRouterHost,
+         builtins: bool = True,
+         status: ty.Optional[str] = None,
          *args, **kwargs
    ):
       if status:
@@ -71,28 +66,27 @@ class FluxClient(discord.Client):
          from .cog.builtins import Builtins
          self.register_cog(Builtins)
 
-   def dispatch(self, event, *args, **kwargs):
+   def dispatch(self, event, *args, **kwargs) -> None:
       super(FluxClient, self).dispatch(event, *args, **kwargs)
-      aio.create_task(self.router.submit(FluxEvent(self, f":{event}", *args, **kwargs)))
+      aio.create_task(self.router.submit(
+         FluxEvent(self, f":{event}", *args, **kwargs)))
 
-   def register_cog(self, cog: ty.Type[FluxCog], name: str = None):
+   def register_cog(self, cog: ty.Type[FluxCog], name: str = None) -> None:
       c = cog(flux=self, name=name)
       logger.success(f"Registered {c}")
       self.cogs.append(c)
 
-   async def startup(self, token, *args, **kwargs):
-
-
+   async def startup(self, token, *args, **kwargs) -> None:
       await aio.gather(*[cog.startup() for cog in self.cogs])
       await self.start(token, *args, **kwargs)
 
-   async def shutdown(self, *args, **kwargs):
-      await self.logout()
+   async def shutdown(self, *args, **kwargs) -> None:
+      await self.close()
 
-   def register_listeners(self):
+   def register_listeners(self) -> None:
       @self.router.listen_for(":message")
       @aur.Eventful.decompose
-      async def _(message: discord.Message):
+      async def _(message: discord.Message) -> None:
          if not message.content or message.author is self.user:
             return
          if message.guild:
@@ -126,8 +120,22 @@ class FluxClient(discord.Client):
       async def _(g: discord.Guild):
          logger.info(f"Removed from guild: {g}")
 
-   async def get_user_s(self, user_id: int):
-      return self.get_user(user_id) or await self.fetch_user(user_id)
+   async def get_user_s(self, user_id: int) -> ty.Optional[discord.User]:
+      try:
+         return self.get_user(user_id) or await self.fetch_user(user_id)
+      except discord.errors.NotFound:
+         return None
 
-   async def get_member_s(self, g: discord.Guild, member_id: int):
-      return g.get_member(member_id) or await g.fetch_member(member_id)
+   async def get_member_s(self, g: discord.Guild, member_id: int) -> ty.Optional[discord.Member]:
+      try:
+         return g.get_member(member_id) or await g.fetch_member(member_id)
+      except discord.errors.NotFound:
+         return None
+
+   async def get_channel_s(
+         self, id_: int
+   ) -> ty.Optional[ty.Union[discord.abc.GuildChannel, discord.abc.PrivateChannel]]:
+      try:
+         return self.get_channel(id_) or await self.fetch_channel(id_)
+      except (discord.NotFound, discord.Forbidden, discord.HTTPException):
+         return None
